@@ -7,7 +7,7 @@ function (x, r, N, log = FALSE)
     N <- rep(N, length.out = M)
     rho <- rep(FALSE, length.out = M)
     value <- .C("dFriedmanR", as.double(x), as.integer(r), as.integer(N), 
-        as.integer(M), as.integer(rho), val = double(M))$val
+        as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -21,7 +21,7 @@ function (x, a, k, N, log = FALSE)
     k <- rep(k, length.out = M)
     N <- rep(N, length.out = M)
     value <- .C("dghyperR", as.integer(x), as.double(a), as.double(k), 
-        as.double(N), as.integer(M), val = double(M))$val
+        as.double(N), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -34,7 +34,7 @@ function (x, nu, lambda, log = FALSE)
     nu <- rep(nu, length.out = N)
     lambda <- rep(lambda, length.out = N)
     value <- .C("dinvGaussR", as.double(x), as.double(nu), as.double(lambda), 
-        as.integer(N), lambda = double(N))$lambda
+        as.integer(N), lambda = double(N),PACKAGE="SuppDists")$lambda
     if (log == TRUE) 
         value <- log(value)
     value
@@ -75,7 +75,7 @@ function (x, parms, log = FALSE)
     type <- rep(type, length.out = N)
     value <- .C("dJohnsonR", as.double(x), as.double(gamma), 
         as.double(delta), as.double(xi), as.double(lambda), as.integer(type), 
-        as.integer(N), val = double(N))$val
+        as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -87,7 +87,7 @@ function (x, N, log = FALSE)
     x <- rep(x, length.out = M)
     N <- rep(N, length.out = M)
     value <- .C("dKendallR", as.integer(N), as.double(x), as.integer(M), 
-        val = double(M))$val
+        val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -103,7 +103,7 @@ function (x, c, N, U, log = FALSE)
     Ns <- rep(FALSE, length.out = M)
     value <- .C("dKruskalWallisR", as.double(x), as.integer(c), 
         as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-        val = double(M))$val
+        val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -118,7 +118,7 @@ function (x, df, k, log = FALSE)
     df <- rep(df, length.out = N)
     k <- rep(k, length.out = N)
     .C("dmaxFratioR", as.double(x), as.integer(df), as.integer(k), 
-        as.integer(N), val = double(N))$val
+        as.integer(N), val = double(N),PACKAGE="SuppDists")$val
 }
 dNormScore <-
 function (x, c, N, U, log = FALSE) 
@@ -131,7 +131,7 @@ function (x, c, N, U, log = FALSE)
     Ns <- rep(TRUE, length.out = M)
     value <- .C("dKruskalWallisR", as.double(x), as.integer(c), 
         as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-        val = double(M))$val
+        val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -144,7 +144,7 @@ function (x, N, rho = 0, log = FALSE)
     rho <- rep(rho, length.out = M)
     N <- rep(N, length.out = M)
     value <- .C("dcorrR", as.double(x), as.double(rho), as.integer(N), 
-        as.integer(M), val = double(M))$val
+        as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -158,7 +158,7 @@ function (x, r, log = FALSE)
     N <- rep(2, length.out = M)
     rho <- rep(TRUE, length.out = M)
     value <- .C("dFriedmanR", as.double(x), as.integer(r), as.integer(N), 
-        as.integer(M), as.integer(rho), val = double(M))$val
+        as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     if (log == TRUE) 
         value <- log(value)
     value
@@ -176,7 +176,7 @@ function (t, moment = "quant")
         value <- .C("JohnsonMomentFitR", as.double(mu), as.double(sigma), 
             as.double(skew), as.double(kurt), gamma = double(1), 
             delta = double(1), xi = double(1), lambda = double(1), 
-            type = integer(1))
+            type = integer(1),PACKAGE="SuppDists")
     }
     else if (firstChar=="u") {
       mu<-t[1]
@@ -186,7 +186,7 @@ function (t, moment = "quant")
       value <- .C("JohnsonMomentFitR", as.double(mu), as.double(sigma), 
           as.double(skew), as.double(kurt), gamma = double(1), 
           delta = double(1), xi = double(1), lambda = double(1), 
-          type = integer(1))
+          type = integer(1),PACKAGE="SuppDists")
      }
     else if (firstChar=="q") {
         input <- quantile(t, probs = c(0.05, 0.206, 0.5, 0.794, 
@@ -199,7 +199,7 @@ function (t, moment = "quant")
         value <- .C("JohnsonFitR", as.double(x95), as.double(x79.4), 
             as.double(x50), as.double(x20.6), as.double(x5), 
             gamma = double(1), delta = double(1), xi = double(1), 
-            lambda = double(1), type = integer(1))
+            lambda = double(1), type = integer(1),PACKAGE="SuppDists")
     }
     else return(NA)
     types <- c("SN", "SL", "SU", "SB")
@@ -250,7 +250,7 @@ function (N)
         length(N)
     else N
     M <- N%/%2
-    value <- .C("normOrdR", val = double(M), as.integer(N), as.integer(M))$val
+    value <- .C("normOrdR", val = double(M), as.integer(N), as.integer(M),PACKAGE="SuppDists")$val
     if (0 == N%%2) 
         c(-value, rev(value))
     else c(-value, 0, rev(value))
@@ -265,11 +265,11 @@ function (q, r, N, lower.tail = TRUE, log.p = FALSE)
     rho <- rep(FALSE, length.out = M)
     if (lower.tail == TRUE) {
         value <- .C("pFriedmanR", as.double(q), as.integer(r), 
-            as.integer(N), as.integer(M), as.integer(rho), val = double(M))$val
+            as.integer(N), as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uFriedmanR", as.double(q), as.integer(r), 
-            as.integer(N), as.integer(M), as.integer(rho), val = double(M))$val
+            as.integer(N), as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -285,11 +285,11 @@ function (q, a, k, N, lower.tail = TRUE, log.p = FALSE)
     N <- rep(N, length.out = M)
     if (lower.tail == TRUE) {
         value <- .C("pghyperR", as.integer(q), as.double(a), 
-            as.double(k), as.double(N), as.integer(M), val = double(M))$val
+            as.double(k), as.double(N), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("ughyperR", as.integer(q), as.double(a), 
-            as.double(k), as.double(N), as.integer(M), val = double(M))$val
+            as.double(k), as.double(N), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -304,11 +304,11 @@ function (q, nu, lambda, lower.tail = TRUE, log.p = FALSE)
     lambda <- rep(lambda, length.out = N)
     if (lower.tail == TRUE) {
         value <- .C("pinvGaussR", as.double(q), as.double(nu), 
-            as.double(lambda), as.integer(N), val = double(N))$val
+            as.double(lambda), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uinvGaussR", as.double(q), as.double(nu), 
-            as.double(lambda), as.integer(N), val = double(N))$val
+            as.double(lambda), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -351,12 +351,12 @@ function (q, parms, lower.tail = TRUE, log.p = FALSE)
     if (lower.tail == TRUE) {
         value <- .C("pJohnsonR", as.double(q), as.double(gamma), 
             as.double(delta), as.double(xi), as.double(lambda), 
-            as.integer(type), as.integer(N), val = double(N))$val
+            as.integer(type), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uJohnsonR", as.double(q), as.double(gamma), 
             as.double(delta), as.double(xi), as.double(lambda), 
-            as.integer(type), as.integer(N), val = double(N))$val
+            as.integer(type), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -370,11 +370,11 @@ function (q, N, lower.tail = TRUE, log.p = FALSE)
     N <- rep(N, length.out = M)
     if (lower.tail == TRUE) {
         value <- .C("pKendallR", as.integer(N), as.double(q), 
-            as.integer(M), val = double(M))$val
+            as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uKendallR", as.integer(N), as.double(q), 
-            as.integer(M), val = double(M))$val
+            as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -392,12 +392,12 @@ function (q, c, N, U, lower.tail = TRUE, log.p = FALSE)
     if (lower.tail == TRUE) {
         value <- .C("pKruskalWallisR", as.double(q), as.integer(c), 
             as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-            val = double(M))$val
+            val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uKruskalWallisR", as.double(q), as.integer(c), 
             as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-            val = double(M))$val
+            val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -412,11 +412,11 @@ function (q, df, k, lower.tail = TRUE, log.p = FALSE)
     k <- rep(k, length.out = N)
     if (lower.tail == TRUE) {
         value <- .C("pmaxFratioR", as.double(q), as.integer(df), 
-            as.integer(k), as.integer(N), val = double(N))$val
+            as.integer(k), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("umaxFratioR", as.double(q), as.integer(df), 
-            as.integer(k), as.integer(N), val = double(N))$val
+            as.integer(k), as.integer(N), val = double(N),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -434,12 +434,12 @@ function (q, c, N, U, lower.tail = TRUE, log.p = FALSE)
     if (lower.tail == TRUE) {
         value <- .C("pKruskalWallisR", as.double(q), as.integer(c), 
             as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-            val = double(M))$val
+            val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uKruskalWallisR", as.double(q), as.integer(c), 
             as.integer(n), as.double(U), as.integer(Ns), as.integer(M), 
-            val = double(M))$val
+            val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -454,11 +454,11 @@ function (q, N, rho = 0, lower.tail = TRUE, log.p = FALSE)
     N <- rep(N, length.out = M)
     if (lower.tail == TRUE) {
         value <- .C("pcorrR", as.double(q), as.double(rho), as.integer(N), 
-            as.integer(M), val = double(M))$val
+            as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("ucorrR", as.double(q), as.double(rho), as.integer(N), 
-            as.integer(M), val = double(M))$val
+            as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -474,11 +474,11 @@ function (q, r, lower.tail = TRUE, log.p = FALSE)
     rho <- rep(TRUE, length.out = M)
     if (lower.tail == TRUE) {
         value <- .C("pFriedmanR", as.double(q), as.integer(r), 
-            as.integer(N), as.integer(M), as.integer(rho), val = double(M))$val
+            as.integer(N), as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     }
     else {
         value <- .C("uFriedmanR", as.double(q), as.integer(r), 
-            as.integer(N), as.integer(M), as.integer(rho), val = double(M))$val
+            as.integer(N), as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
     }
     if (log.p == TRUE) 
         value <- log(value)
@@ -497,7 +497,7 @@ function (p, r, N, lower.tail = TRUE, log.p = FALSE)
     N <- rep(N, length.out = M)
     rho <- rep(FALSE, length.out = M)
     .C("qFriedmanR", as.double(p), as.integer(r), as.integer(N), 
-        as.integer(M), as.integer(rho), val = double(M))$val
+        as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
 }
 qghyper <-
 function (p, a, k, N, lower.tail = TRUE, log.p = FALSE) 
@@ -512,7 +512,7 @@ function (p, a, k, N, lower.tail = TRUE, log.p = FALSE)
     k <- rep(k, length.out = M)
     N <- rep(N, length.out = M)
     value <- .C("qghyperR", as.double(p), as.double(a), as.double(k), 
-        as.double(N), as.integer(M), val = double(M))$val
+        as.double(N), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
     value
 }
 qinvGauss <-
@@ -527,7 +527,7 @@ function (p, nu, lambda, lower.tail = TRUE, log.p = FALSE)
     nu <- rep(nu, length.out = N)
     lambda <- rep(lambda, length.out = N)
     .C("qinvGaussR", as.double(p), as.double(nu), as.double(lambda), 
-        as.integer(N), value = double(N))$value
+        as.integer(N), value = double(N),PACKAGE="SuppDists")$value
 }
 qJohnson <-
 function (p, parms, lower.tail = TRUE, log.p = FALSE) 
@@ -569,7 +569,7 @@ function (p, parms, lower.tail = TRUE, log.p = FALSE)
     type <- rep(type, length.out = N)
     .C("qJohnsonR", as.double(p), as.double(gamma), as.double(delta), 
         as.double(xi), as.double(lambda), as.integer(type), as.integer(N), 
-        val = double(N))$val
+        val = double(N),PACKAGE="SuppDists")$val
 }
 qKendall <-
 function (p, N, lower.tail = TRUE, log.p = FALSE) 
@@ -582,7 +582,7 @@ function (p, N, lower.tail = TRUE, log.p = FALSE)
     p <- rep(p, length.out = M)
     N <- rep(N, length.out = M)
     .C("qKendallR", as.integer(N), as.double(p), as.integer(M), 
-        val = double(M))$val
+        val = double(M),PACKAGE="SuppDists")$val
 }
 qKruskalWallis <-
 function (p, c, N, U, lower.tail = TRUE, log.p = FALSE) 
@@ -598,7 +598,7 @@ function (p, c, N, U, lower.tail = TRUE, log.p = FALSE)
     U <- rep(U, length.out = M)
     Ns <- rep(FALSE, length.out = M)
     .C("qKruskalWallisR", as.double(p), as.integer(c), as.integer(N), 
-        as.double(U), as.integer(Ns), as.integer(M), val = double(M))$val
+        as.double(U), as.integer(Ns), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
 }
 qmaxFratio <-
 function (p, df, k, lower.tail = TRUE, log.p = FALSE) 
@@ -612,7 +612,7 @@ function (p, df, k, lower.tail = TRUE, log.p = FALSE)
     df <- rep(df, length.out = N)
     k <- rep(k, length.out = N)
     .C("qmaxFratioR", as.double(p), as.integer(df), as.integer(k), 
-        as.integer(N), val = double(N))$val
+        as.integer(N), val = double(N),PACKAGE="SuppDists")$val
 }
 qNormScore <-
 function (p, c, N, U, lower.tail = TRUE, log.p = FALSE) 
@@ -628,7 +628,7 @@ function (p, c, N, U, lower.tail = TRUE, log.p = FALSE)
     U <- rep(U, length.out = M)
     Ns <- rep(TRUE, length.out = M)
     .C("qKruskalWallisR", as.double(p), as.integer(c), as.integer(N), 
-        as.double(U), as.integer(Ns), as.integer(M), val = double(M))$val
+        as.double(U), as.integer(Ns), as.integer(M), val = double(M),PACKAGE="SuppDists")$val
 }
 qPearson <-
 function (p, N, rho = 0, lower.tail = TRUE, log.p = FALSE) 
@@ -642,7 +642,7 @@ function (p, N, rho = 0, lower.tail = TRUE, log.p = FALSE)
     rho <- rep(rho, length.out = M)
     N <- rep(N, length.out = M)
     .C("qcorrR", as.double(p), as.double(rho), as.integer(N), 
-        as.integer(M), val = double(M))$val
+        as.integer(M), val = double(M),PACKAGE="SuppDists")$val
 }
 qSpearman <-
 function (p, r, lower.tail = TRUE, log.p = FALSE) 
@@ -657,7 +657,7 @@ function (p, r, lower.tail = TRUE, log.p = FALSE)
     N <- rep(2, length.out = M)
     rho <- rep(TRUE, length.out = M)
     .C("qFriedmanR", as.double(p), as.integer(r), as.integer(N), 
-        as.integer(M), as.integer(rho), val = double(M))$val
+        as.integer(M), as.integer(rho), val = double(M),PACKAGE="SuppDists")$val
 }
 rFriedman <-
 function (n, r, N) 
@@ -670,7 +670,7 @@ function (n, r, N)
     N <- rep(N, length.out = M)
     rho <- rep(FALSE, length.out = M)
     .C("rFriedmanR", as.integer(r), as.integer(N), as.integer(rho), 
-        as.integer(n), as.integer(M), value = double(n))$value
+        as.integer(n), as.integer(M), value = double(n),PACKAGE="SuppDists")$value
 }
 rghyper <-
 function (n, a, k, N) 
@@ -683,7 +683,7 @@ function (n, a, k, N)
     k <- rep(k, length.out = K)
     N <- rep(N, length.out = K)
     .C("rghyperR", as.double(a), as.double(k), as.double(N), 
-        as.integer(n), as.integer(K), value = double(n))$value
+        as.integer(n), as.integer(K), value = double(n),PACKAGE="SuppDists")$value
 }
 rinvGauss <-
 function (n, nu, lambda) 
@@ -695,7 +695,7 @@ function (n, nu, lambda)
     nu <- rep(nu, length.out = N)
     lambda <- rep(lambda, length.out = N)
     .C("rinvGaussR", as.double(nu), as.double(lambda), as.integer(n), 
-        as.integer(N), value = double(n))$value
+        as.integer(N), value = double(n),PACKAGE="SuppDists")$value
 }
 rJohnson <-
 function (n, parms) 
@@ -730,7 +730,7 @@ function (n, parms)
     M <- length(gamma)
     .C("rJohnsonR", as.double(gamma), as.double(delta), as.double(xi), 
         as.double(lambda), as.integer(type), as.integer(n), as.integer(M), 
-        val = double(n))$val
+        val = double(n),PACKAGE="SuppDists")$val
 }
 rKendall <-
 function (n, N) 
@@ -740,7 +740,7 @@ function (n, N)
     else n
     M <- length(N)
     .C("rKendallR", as.integer(N), as.integer(n), as.integer(M), 
-        val = double(n))$val
+        val = double(n),PACKAGE="SuppDists")$val
 }
 rKruskalWallis <-
 function (n, c, N, U) 
@@ -755,7 +755,7 @@ function (n, c, N, U)
     Ns <- rep(FALSE, length.out = M)
     .C("rKruskalWallisR", randArray = double(n), as.integer(n), 
         as.integer(M), as.integer(c), as.integer(N), as.double(U), 
-        as.integer(Ns), )$randArray
+        as.integer(Ns),PACKAGE="SuppDists" )$randArray
 }
 rmaxFratio <-
 function (n, df, k) 
@@ -767,7 +767,7 @@ function (n, df, k)
     df <- rep(df, length.out = M)
     k <- rep(k, length.out = M)
     .C("rmaxFratioR", as.integer(df), as.integer(k), as.integer(n), 
-        as.integer(M), value = double(n))$value
+        as.integer(M), value = double(n),PACKAGE="SuppDists")$value
 }
 rMWC1019 <-
 function (n, new.start = FALSE, seed = 556677) 
@@ -776,7 +776,7 @@ function (n, new.start = FALSE, seed = 556677)
         n
     else length(n)
     .C("MWC1019R", val = double(n), as.integer(n), as.integer(new.start), 
-        as.integer(seed))$val
+        as.integer(seed),PACKAGE="SuppDists")$val
 }
 rNormScore <-
 function (n, c, N, U) 
@@ -791,7 +791,7 @@ function (n, c, N, U)
     Ns <- rep(TRUE, length.out = M)
     .C("rKruskalWallisR", randArray = double(n), as.integer(n), 
         as.integer(M), as.integer(c), as.integer(N), as.double(U), 
-        as.integer(Ns), )$randArray
+        as.integer(Ns),PACKAGE="SuppDists" )$randArray
 }
 rPearson <-
 function (n, N, rho = 0) 
@@ -803,7 +803,7 @@ function (n, N, rho = 0)
     rho <- rep(rho, length.out = M)
     N <- rep(N, length.out = M)
     .C("rcorrR", as.double(rho), as.integer(N), as.integer(n), 
-        as.integer(M), val = double(n))$val
+        as.integer(M), val = double(n),PACKAGE="SuppDists")$val
 }
 rSpearman <-
 function (n, r) 
@@ -816,7 +816,7 @@ function (n, r)
     N <- rep(2, length.out = M)
     rho <- rep(TRUE, length.out = M)
     .C("rFriedmanR", as.integer(r), as.integer(N), as.integer(rho), 
-        as.integer(n), as.integer(M), value = double(n))$value
+        as.integer(n), as.integer(M), value = double(n),PACKAGE="SuppDists")$value
 }
 rziggurat <-
 function (n, normal = TRUE, new.start = FALSE, seed = 556677) 
@@ -825,7 +825,7 @@ function (n, normal = TRUE, new.start = FALSE, seed = 556677)
         length(n)
     else n
    .C("ziggR", val = double(n), as.integer(n), as.integer(normal), 
-        as.integer(new.start), as.integer(seed))$val
+        as.integer(new.start), as.integer(seed),PACKAGE="SuppDists")$val
 }
 sFriedman <-
 function (r, N) 
@@ -836,7 +836,7 @@ function (r, N)
     rho <- rep(FALSE, length.out = M)
     value <- .C("sFriedmanR", as.integer(r), as.integer(N), as.integer(rho), 
         as.integer(M), mn = double(M), med = double(M), mod = double(M), 
-        var = double(M), third = double(M), fourth = double(M))
+        var = double(M), third = double(M), fourth = double(M),PACKAGE="SuppDists")
     aList <- list(title = "Friedman's chi-square", r = r, N = N)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
         value$third, value$fourth, -1)
@@ -850,7 +850,7 @@ function (a, k, N)
     N <- rep(N, length.out = M)
     value <- .C("sghyperR", as.double(a), as.double(k), as.double(N), 
         as.integer(M), mn = double(M), med = double(M), mod = double(M), 
-        var = double(M), third = double(M), fourth = double(M))
+        var = double(M), third = double(M), fourth = double(M),PACKAGE="SuppDists")
     aList <- list(title = "Generalized Hypergeometric", a = a, 
         k = k, N = N)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
@@ -906,7 +906,7 @@ function (parms)
     value <- .C("sJohnsonR", as.double(gamma), as.double(delta), 
         as.double(xi), as.double(lambda), as.integer(type), as.integer(N), 
         mn = double(N), med = double(N), mod = double(N), var = double(N), 
-        third = double(N), fourth = double(N))
+        third = double(N), fourth = double(N),PACKAGE="SuppDists")
     aList <- list(title = "Johnson Distribution", gamma = gamma, 
         delta = delta, xi = xi, lambda = lambda, type = type)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
@@ -922,7 +922,7 @@ function (N)
     third <- rep(0, length.out = M)
     var <- (4 * N + 10)/(9 * N * (N - 1))
     fourth <- .C("fourthKendallR", as.integer(N), as.integer(M), 
-        val = double(M))$val
+        val = double(M),PACKAGE="SuppDists")$val
     aList <- list(title = "Kendall's Tau", N = N)
     makeStatList(aList, mn, med, var, mod, third, fourth, -1)
 }
@@ -936,7 +936,7 @@ function (c, N, U)
     Ns <- rep(FALSE, length.out = M)
     value <- .C("sKruskalWallisR", as.integer(c), as.integer(n), 
         as.double(U), as.integer(Ns), as.integer(M), var = double(M), 
-        mod = double(M), third = double(M), fourth = double(M))
+        mod = double(M), third = double(M), fourth = double(M),PACKAGE="SuppDists")
     mn <- (c - 1)
     aList <- list(title = "Kruskal Wallis", c = c, N = n, U = U)
     median <- qKruskalWallis(0.5, c, n, U, Ns)
@@ -951,7 +951,7 @@ function (df, k)
     k <- rep(k, length.out = N)
     value <- .C("smaxFratioR", as.integer(df), as.integer(k), 
         as.integer(N), mn = double(N), med = double(N), mod = double(N), 
-        var = double(N), third = double(N), fourth = double(N))
+        var = double(N), third = double(N), fourth = double(N),PACKAGE="SuppDists")
     aList <- list(title = "Maximum F ratio", df = df, k = k)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
         value$third, value$fourth, 2)
@@ -966,7 +966,7 @@ function (c, N, U)
     Ns <- rep(TRUE, length.out = M)
     value <- .C("sKruskalWallisR", as.integer(c), as.integer(n), 
         as.double(U), as.integer(Ns), as.integer(M), var = double(M), 
-        mod = double(M), third = double(M), fourth = double(M))
+        mod = double(M), third = double(M), fourth = double(M),PACKAGE="SuppDists")
     mn <- (c - 1)
     aList <- list(title = "Normal Scores", c = c, N = n, U = U)
     median <- qNormScore(0.5, c, n, U)
@@ -981,7 +981,7 @@ function (N, rho = 0)
     N <- rep(N, length.out = M)
     value <- .C("scorrR", as.double(rho), as.integer(N), as.integer(M), 
         mn = double(M), med = double(M), mod = double(M), var = double(M), 
-        third = double(M), fourth = double(M))
+        third = double(M), fourth = double(M),PACKAGE="SuppDists")
     aList <- list(title = "Correlation coefficient", rho = rho, 
         N = N)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
@@ -996,7 +996,7 @@ function (r)
     rho <- rep(TRUE, length.out = M)
     value <- .C("sFriedmanR", as.integer(r), as.integer(N), as.integer(rho), 
         as.integer(M), mn = double(M), med = double(M), mod = double(M), 
-        var = double(M), third = double(M), fourth = double(M))
+        var = double(M), third = double(M), fourth = double(M),PACKAGE="SuppDists")
     aList <- list(title = "Spearman's rho", r = r)
     makeStatList(aList, value$mn, value$med, value$var, value$mod, 
         value$third, value$fourth, -1)
@@ -1005,6 +1005,6 @@ tghyper <-
 function (a, k, N) 
 {
     value <- .C("tghyperR", as.double(a), as.double(k), as.double(N), 
-        strn =paste(rep(" ", 128), collapse="")  )
+        strn =paste(rep(" ", 128), collapse=""),PACKAGE="SuppDists"  )
 	value$strn
 }
